<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon">
	<!--The common transformations-->
	<xsl:import href="Common.xsl"/>
	<!--The transformations concerning the release-->
	<xsl:import href="Release.xsl"/>
	<!--The transformations concerning the resume-->
	<xsl:import href="CV.xsl"/>
	<xsl:output method="html" indent="yes" standalone="yes"/>
	<!--The lang that is used every time a decision has to be made concerning translation-->
	<!--'en' by default; note that the parameter must be surrounded by single quotes!-->
	<xsl:param name="lang" select="'en'" saxon:assignable="yes"/>
	<!--The system-dependant path directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_path"/>
	<!--The URL of the directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_url"/>
	<!--The URL PHP common file that is included within the generated HTML content files-->
	<xsl:param name="php_url"/>
	<!--The mySQL server location-->
	<xsl:param name="mysql_host_name"/>
	<!--The mySQL user name-->
	<xsl:param name="mysql_user_name"/>
	<!--The mySQL user password-->
	<xsl:param name="mysql_user_password"/>
	<!--The mySQL database name-->
	<xsl:param name="mysql_database_name"/>
	<xsl:template match="/Document">
		<xsl:param name="portal_document"/>
		<xsl:variable name="content_file">
			<xsl:call-template name="print_html_content_file_path">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="menu_file">
			<xsl:call-template name="print_html_menu_file_path">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="index_file">
			<xsl:call-template name="print_html_index_file_path">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<!--The name of the inner HTML frame file-->
		<xsl:variable name="inner_frame_file">
			<xsl:call-template name="print_html_inner_frame_file_path">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<!--The name of the main HTML file-->
		<xsl:variable name="top_file">
			<xsl:call-template name="print_html_top_file_path">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="not(@generate = 'no')">
			<xsl:document href="{$content_file}">
				<xsl:call-template name="_write_content">
					<xsl:with-param name="portal_document" select="$portal_document"/>
				</xsl:call-template>
			</xsl:document>
		</xsl:if>
		<xsl:if test="not($generate_frames = 'no')">
			<xsl:if test="not(@generate = 'no')">
				<xsl:document href="{$menu_file}">
					<xsl:call-template name="_write_menu">
						<xsl:with-param name="portal_document" select="$portal_document"/>
					</xsl:call-template>
				</xsl:document>
			</xsl:if>
			<xsl:document href="{$index_file}">
				<xsl:call-template name="write_index">
					<xsl:with-param name="portal_document" select="$portal_document"/>
				</xsl:call-template>
			</xsl:document>
			<xsl:document href="{$top_file}">
				<xsl:call-template name="write_top">
					<xsl:with-param name="index_file">
						<xsl:call-template name="print_html_index_file_path">
							<xsl:with-param name="portal_document" select="$portal_document"/>
							<xsl:with-param name="url" select="'yes'"/>
							<xsl:with-param name="relative" select="'yes'"/>
						</xsl:call-template>
					</xsl:with-param>
					<xsl:with-param name="inner_frame_file">
						<xsl:call-template name="print_html_inner_frame_file_path">
							<xsl:with-param name="portal_document" select="$portal_document"/>
							<xsl:with-param name="url" select="'yes'"/>
							<xsl:with-param name="relative" select="'yes'"/>
						</xsl:call-template>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:document>
			<xsl:if test="not(@generate = 'no')">
				<xsl:document href="{$inner_frame_file}">
					<xsl:call-template name="_write_inner_frame">
						<xsl:with-param name="menu_file">
							<xsl:call-template name="print_html_menu_file_path">
								<xsl:with-param name="portal_document" select="$portal_document"/>
								<xsl:with-param name="url" select="'yes'"/>
								<xsl:with-param name="relative" select="'yes'"/>
							</xsl:call-template>
						</xsl:with-param>
						<xsl:with-param name="content_file">
							<xsl:call-template name="print_html_content_file_path">
								<xsl:with-param name="portal_document" select="$portal_document"/>
								<xsl:with-param name="url" select="'yes'"/>
								<xsl:with-param name="relative" select="'yes'"/>
							</xsl:call-template>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:document>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="Keywords">
		<meta name="Keywords">
			<xsl:attribute name="content">
				<xsl:for-each select="//Keyword">
					<xsl:variable name="keyword">
						<xsl:apply-templates select="."/>
					</xsl:variable>
					<xsl:value-of select="normalize-space($keyword)"/>
					<xsl:if test="position() != last()">,</xsl:if>
				</xsl:for-each>
			</xsl:attribute>
		</meta>
	</xsl:template>
	<xsl:template match="Section">
		<a>
			<xsl:attribute name="name">
				<xsl:call-template name="print_section_aname"/>
			</xsl:attribute>
		</a>
		<xsl:variable name="indent" select="count(ancestor::Section) + 2"/>
		<xsl:element name="h{$indent}">
			<xsl:call-template name="_print_section_title"/>
		</xsl:element>
		<xsl:apply-templates select="Body"/>
	</xsl:template>
	<xsl:template name="_print_section_title">
		<xsl:choose>
			<xsl:when test="count(Title) > 0">
				<xsl:apply-templates select="Title"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@title"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the top index of the generated HTML page-->
	<!--The current node should be the root node of the portal document-->
	<!--The portal_document should be given as parameter-->
	<xsl:template name="_print_top_index">
		<xsl:param name="portal_document"/>
		<xsl:call-template name="_print_top_banner"/>
		<xsl:call-template name="_print_navigation_part_new">
			<xsl:with-param name="portal_document" select="$portal_document"/>
		</xsl:call-template>
	</xsl:template>
	<!--Prints the navigation part that enables to navigate throught the whole site-->
	<!--The portal_document parameter should be provided-->
	<xsl:template name="_print_navigation_part_old">
		<xsl:param name="portal_document"/>
		<xsl:variable name="separator" select="'&#149;'"/>
		<xsl:variable name="topics">
			<xsl:call-template name="print_portal_topics"/>
		</xsl:variable>
		<xsl:variable name="topic_title">
			<xsl:value-of select="$topics/Topic/Documents/Document[@IDREF = $portal_document/@IDREF]/../../@title"/>
		</xsl:variable>
		<table class="banner_index_top">
			<tr>
				<td>
					<xsl:text>Topics:&#160;&#160;</xsl:text>
					<xsl:for-each select="$topics/Topic">
						<xsl:variable name="main_document" select="Documents/Document[@main = 'yes']"/>
						<xsl:variable name="html_file">
							<xsl:call-template name="print_html_target_file_path">
								<xsl:with-param name="portal_document" select="$main_document"/>
								<xsl:with-param name="url" select="'yes'"/>
								<xsl:with-param name="relative" select="'yes'"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:choose>
							<xsl:when test="@title != $topic_title">
								<a target="_top">
									<xsl:attribute name="href">
										<xsl:value-of select="$html_file"/>
									</xsl:attribute>
									<xsl:value-of select="@title"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
								<b><![CDATA[>>]]>&#160;<xsl:value-of select="@title"/>&#160;<![CDATA[<<]]></b>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="position() != last()">
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$separator" disable-output-escaping="no"/>
							<xsl:text>&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
		</table>
		<table class="banner_index_bottom">
			<tr>
				<td>
					<xsl:text>Pages of the topic:&#160;&#160;</xsl:text>
					<xsl:for-each select="$topics/Topic[@title = $topic_title]/Documents/Document">
						<xsl:variable name="html_file">
							<xsl:call-template name="print_html_target_file_path">
								<xsl:with-param name="portal_document" select="."/>
								<xsl:with-param name="url" select="'yes'"/>
								<xsl:with-param name="relative" select="'yes'"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="is_selected">
							<xsl:value-of select="@IDREF = $portal_document/@IDREF and ((count(@xml:lang) = 0) or (@xml:lang = $portal_document/@xml:lang))"/>
						</xsl:variable>
						<xsl:variable name="target" select="'_top'"/>
						<xsl:variable name="title">
							<xsl:call-template name="print_document_title">
								<xsl:with-param name="portal_document" select="."/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:choose>
							<xsl:when test="$is_selected = 'true'">
								<b><![CDATA[>>]]>&#160;<xsl:value-of select="$title"/>&#160;<![CDATA[<<]]></b>
							</xsl:when>
							<xsl:otherwise>
								<a target="{$target}">
									<xsl:attribute name="href">
										<xsl:value-of select="$html_file"/>
									</xsl:attribute>
									<xsl:value-of select="$title"/>
								</a>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="position() != last()">
							<xsl:text disable-output-escaping="no">&#160;</xsl:text>
							<xsl:value-of select="$separator" disable-output-escaping="no"/>
							<xsl:text disable-output-escaping="no">&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!--Prints the navigation part that enables to navigate throught the whole site-->
	<!--The portal_document parameter should be provided-->
	<xsl:template name="_print_navigation_part_new">
		<xsl:param name="portal_document"/>
		<xsl:variable name="topics">
			<xsl:call-template name="print_portal_topics"/>
		</xsl:variable>
		<xsl:variable name="topic_title" select="$topics/Topic/Documents/Document[@IDREF = $portal_document/@IDREF]/../../@title"/>
		<xsl:variable name="target" select="'_top'"/>
		<!--div class="tabs">
			<xsl:for-each select="$topics/Topic">
				<xsl:variable name="main_document" select="Documents/Document[@main = 'yes']"/>
				<xsl:variable name="html_file">
					<xsl:call-template name="print_html_target_file_path">
						<xsl:with-param name="portal_document" select="$main_document"/>
						<xsl:with-param name="url" select="'yes'"/>
						<xsl:with-param name="relative" select="'yes'"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="is_selected" select="@title = $topic_title"/>				<xsl:choose>
					<xsl:when test="$is_selected">
						<span class="selected">
							<xsl:value-of select="@title"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<a target="{$target}">
							<xsl:attribute name="href">
								<xsl:value-of select="$html_file"/>
							</xsl:attribute>
							<span class="unselected">
								<xsl:value-of select="@title"/>
							</span>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</div-->
		<div class="tabs">
			<a target="{$target}" class="unselected">
				<xsl:attribute name="href">
					<xsl:value-of select="'index.html'"/>
				</xsl:attribute>.. (parent)</a>
			<xsl:for-each select="$topics/Topic[@title = $topic_title]/Documents/Document">
				<xsl:variable name="html_file">
					<xsl:call-template name="print_html_target_file_path">
						<xsl:with-param name="portal_document" select="."/>
						<xsl:with-param name="url" select="'yes'"/>
						<xsl:with-param name="relative" select="'yes'"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="is_selected" select="@IDREF = $portal_document/@IDREF and ((count(@xml:lang) = 0) or (@xml:lang = $portal_document/@xml:lang))"/>
				<xsl:variable name="title">
					<xsl:call-template name="print_document_title">
						<xsl:with-param name="portal_document" select="."/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$is_selected">
						<span class="selected">
							<xsl:value-of select="$title"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<a target="{$target}" class="unselected">
							<xsl:attribute name="href">
								<xsl:value-of select="$html_file"/>
							</xsl:attribute>
							<xsl:value-of select="$title"/>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</div>
		<xsl:variable name="page_title">
			<xsl:call-template name="print_document_title">
				<xsl:with-param name="portal_document" select="$portal_document"/>
			</xsl:call-template>
		</xsl:variable>
		<div class="underTabs">You are here:&#160;<xsl:value-of select="$topic_title"/>&#160;<![CDATA[>>]]>&#160;<xsl:value-of select="$page_title"/>
		</div>
	</xsl:template>
	<!--Prints the top banner which is displayed on every one of the generated HTML page-->
	<xsl:template name="_print_top_banner">
		<xsl:variable name="portal">
			<xsl:call-template name="print_portal_information"/>
		</xsl:variable>
		<table class="banner_title">
			<tr>
				<th align="left">
					<xsl:choose>
						<xsl:when test="count($portal/Portal/Logo/@ref) >0">
							<img src="{$portal/Portal/Logo/@ref}" alt="{$portal/Portal/Title}"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="$portal/Portal/Title"/>
						</xsl:otherwise>
					</xsl:choose>
				</th>
				<td align="right">
					<xsl:apply-templates select="$portal/Portal/Email"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!--Prints the topics at the the top of the HTML page-->
	<!--the portal_document and topic_title should be given as parameters-->
	<xsl:template name="_print_top_index_topics">
		<xsl:param name="portal_document"/>
		<xsl:param name="topic_title"/>
		<xsl:variable name="topics">
			<xsl:call-template name="print_portal_topics"/>
		</xsl:variable>
		<table class="banner_index_top" cellspacing="0" cellpadding="0">
			<tr>
				<td>
					<xsl:text>Topics:&#160;&#160;</xsl:text>
					<xsl:for-each select="$topics/Topic">
						<xsl:variable name="html_file">
							<xsl:call-template name="print_html_target_file_path">
								<xsl:with-param name="portal_document" select="Documents/Document[@main = 'yes']"/>
								<xsl:with-param name="url" select="'yes'"/>
								<xsl:with-param name="relative" select="'yes'"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="xml_file">
							<xsl:call-template name="print_xml_file_path">
								<xsl:with-param name="document_id" select="Documents/Document[@main = 'yes']/@IDREF"/>
							</xsl:call-template>
						</xsl:variable>
						<td align="right">
							<img src="..\source\images\html\menu_down_left.gif" alt="coucou"/>
						</td>
						<td>
							<font>
								<xsl:choose>
									<xsl:when test="@title != $topic_title">
										<a target="_top">
											<xsl:attribute name="href">
												<xsl:value-of select="$html_file"/>
											</xsl:attribute>
											<xsl:value-of select="@title"/>
										</a>
									</xsl:when>
									<xsl:otherwise>
										<b>
											<xsl:value-of select="@title"/>
										</b>
									</xsl:otherwise>
								</xsl:choose>
							</font>
						</td>
						<td align="left">-</td>
					</xsl:for-each>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!--Prints the top part of the HTML content file -->
	<!--This template must be called from the Document element-->
	<!--The equivalent _print_content_bottom_part must be called after the content page has been generated-->
	<xsl:template name="_print_content_top_part">
		<table class="wrapper">
			<tr>
				<td>Generation timestamp: <code>
						<xsl:value-of select="$date"/>
					</code>
				</td>
				<xsl:if test="Info/LastUpdateDate">
					<td>Last modification date: <code>
							<xsl:value-of select="Info/LastUpdateDate"/>
						</code>
					</td>
				</xsl:if>
				<xsl:if test="Info/CreationDate">
					<td>Creation date: <code>
							<xsl:value-of select="Info/CreationDate"/>
						</code>
					</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>
	<!--Prints extra stuff on top of the HTML page-->
	<!--This template must be called from the Document element-->
	<xsl:template name="_print_top_extra">
		<xsl:if test="@status = 'uc'">
			<div align="center">
				<img src="Images/hevequip.gif" alt="Under Construction" border="2"/>
			</div>
		</xsl:if>
	</xsl:template>
	<!--Prints the audience and abstract pieces of the HTML-->
	<!--this template must be called from the Document element-->
	<xsl:template name="_print_audience_and_abstract">
		<xsl:if test="Audience or Abstract">
			<table class="audience_abstract">
				<tr>
					<td>
						<xsl:if test="Audience">
							<table class="audience">
								<tr>
									<th>Audience</th>
								</tr>
								<tr>
									<td>
										<xsl:apply-templates select="Audience"/>
									</td>
								</tr>
							</table>
						</xsl:if>
						<xsl:if test="Abstract">
							<div class="abstract">
								<p>
									<xsl:apply-templates select="Abstract"/>
								</p>
							</div>
						</xsl:if>
					</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	<!--Prints the FAQ section. Nothing is written if there is no FAQ.-->
	<!--This template must be called from the Document element-->
	<xsl:template name="_print_faq_section">
		<xsl:if test="count(/Document/Body//Section/FAQ) > 0">
			<span class="boxTitle">
				<nobr>Frequently Asked Questions</nobr>
			</span>
			<div class="box">
				<xsl:for-each select="/Document/Body//Section[count(FAQ) > 0]">
					<xsl:variable name="index">
						<xsl:call-template name="_print_section_index"/>
					</xsl:variable>
					<xsl:variable name="faq">
						<a>
							<xsl:attribute name="href">#<xsl:value-of select="$index"/>
							</xsl:attribute>
							<xsl:apply-templates select="FAQ"/>
						</a>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="(position() mod 2) = 1">
							<div class="odd">
								<xsl:copy-of select="$faq"/>
							</div>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$faq"/>
						</xsl:otherwise>
					</xsl:choose>
					<br/>
				</xsl:for-each>
			</div>
		</xsl:if>
	</xsl:template>
	<!--Prints the table of contents of the generated page; the current node must be an ancestor of the higher "Section" element-->
	<!--This template must be called from the Document element-->
	<!--Prints the information concerning the modification and creation dates-->
	<xsl:template name="_print_table_of_contents">
		<xsl:if test="count(//Section[count(@IDREF) = 0]) > 0">
			<span class="boxTitle">
				<nobr>Table of contents</nobr>
			</span>
			<div class="box">
				<xsl:for-each select="//Section[count(@IDREF) = 0]">
					<xsl:variable name="index">
						<xsl:call-template name="_print_section_index"/>
					</xsl:variable>
					<xsl:variable name="aname">
						<xsl:call-template name="print_section_aname"/>
					</xsl:variable>
					<nobr>
						<xsl:value-of select="$index"/>
						<xsl:text>&#160;</xsl:text>
						<a>
							<xsl:attribute name="href">#<xsl:value-of select="$aname"/>
							</xsl:attribute>
							<xsl:call-template name="_print_section_title"/>
						</a>
					</nobr>
					<br/>
				</xsl:for-each>
			</div>
			<br/>
		</xsl:if>
		<br/>
	</xsl:template>
	<!--Prints the bottom part of the HTML content file -->
	<!--This template must be called from the Document element-->
	<!--The equivalent _print_content_top_part must be have been called beforehand-->
	<xsl:template name="_print_content_bottom_part">
		<table class="wrapper">
			<tr>
				<td>
					<a href="#tothetop">to the top</a>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!--Prints the HTML audit section content file, only if PHP generation is available -->
	<!--this template must be called from the Document element-->
	<xsl:template name="_print_content_audit_part">
		<xsl:if test="$generate_php = 'yes'">
			<table class="wrapper">
				<tr>
					<td align="left">Current date: <code>
							<xsl:text disable-output-escaping="yes">&lt;?php
print_date();
?&gt;</xsl:text>
						</code>
					</td>
					<td align="right">Number of hit: <code>
							<xsl:text disable-output-escaping="yes">&lt;?php
</xsl:text>
							<xsl:text disable-output-escaping="yes">print_hit_number($database, $page_name);
?&gt;</xsl:text>
						</code>
					</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	<!--Prints the copyright for this site generator-->
	<xsl:template name="_print_content_copyright">
		<div class="copyright">Site generated by <strong>
				<i>
					<a href="http://members.lycos.co.uk/wedsitor" target="_blank">WedSitor</a>
				</i>
			</strong>
		</div>
	</xsl:template>
	<!--Prints the content of the HTML content file-->
	<!--A portal_document parameter is expected when no frames are generated-->
	<xsl:template name="_write_content">
		<xsl:param name="portal_document"/>
		<xsl:if test="$portal_document/@xml:lang">
			<xsl:call-template name="set_language">
				<xsl:with-param name="language" select="$portal_document/@xml:lang"/>
			</xsl:call-template>
		</xsl:if>
		<html>
			<head>
				<meta name="robots" content="noindex, nofollow"/>
				<meta name="Author">
					<xsl:attribute name="content">
						<xsl:for-each select="Authors/Person">
							<xsl:value-of select="Name"/>
							<xsl:text/>
						</xsl:for-each>
					</xsl:attribute>
				</meta>
				<meta name="Copyright">
					<xsl:attribute name="content">
						<xsl:for-each select="Authors/Person">
							<xsl:value-of select="Name"/>
							<xsl:text/>
						</xsl:for-each>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="LastUpdateDate"/>
					</xsl:attribute>
				</meta>
				<xsl:apply-templates select="Keywords"/>
				<link rel="StyleSheet" type="text/css">
					<xsl:attribute name="href">
						<xsl:call-template name="_print_content_stylesheet_path"/>
					</xsl:attribute>
				</link>
				<script type="text/javascript" language="javascript">
					<xsl:attribute name="src">
						<xsl:call-template name="_print_javascript_path"/>
					</xsl:attribute>
				</script>
				<title>
					<xsl:variable name="title">
						<xsl:apply-templates select="Title"/>
					</xsl:variable>
					<xsl:value-of select="normalize-space($title)"/>
				</title>
			</head>
			<body>
				<a name="tothetop"/>
				<xsl:if test="$generate_frames = 'no'">
					<xsl:call-template name="_print_top_index">
						<xsl:with-param name="portal_document" select="$portal_document"/>
					</xsl:call-template>
					<br/>
				</xsl:if>
				<xsl:if test="$generate_php = 'yes'">
					<xsl:call-template name="_print_php_audit"/>
				</xsl:if>
				<xsl:call-template name="_print_content_top_part"/>
				<!--xsl:call-template name="_print_top_extra"/-->
				<xsl:call-template name="_print_content_body_part"/>
				<xsl:call-template name="_print_content_bottom_part"/>
				<xsl:call-template name="_print_content_audit_part"/>
				<xsl:if test="$generate_frames = 'no'">
					<xsl:call-template name="_print_navigation_part_new">
						<xsl:with-param name="portal_document" select="$portal_document"/>
					</xsl:call-template>
					<br/>
				</xsl:if>
				<xsl:call-template name="_print_content_copyright"/>
			</body>
		</html>
	</xsl:template>
	<!--Prints the body part of the HTML content file-->
	<!--The current node must be the Document element-->
	<xsl:template name="_print_content_body_part">
		<xsl:choose>
			<xsl:when test="Person">
				<xsl:apply-templates select="Person"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="generate_table_of_contents" select="count(Body) > 0"/>
				<table class="middle">
					<tr>
						<td valign="top" width="20%">
							<font size="-2">
								<xsl:if test="$generate_table_of_contents">
									<a name="tableofcontents"/>
									<xsl:call-template name="_print_table_of_contents"/>
								</xsl:if>
								<xsl:call-template name="_print_faq_section"/>
							</font>
						</td>
						<td width="80%">
							<h1>
								<xsl:apply-templates select="Title"/>
							</h1>
							<xsl:call-template name="_print_audience_and_abstract"/>
							<xsl:apply-templates select="Body"/>
							<br/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the HTML menu file-->
	<xsl:template name="_write_menu">
		<xsl:param name="portal_document"/>
		<html>
			<head>
				<meta name="robots" content="noindex, nofollow"/>
				<link rel="StyleSheet" type="text/css">
					<xsl:attribute name="href">
						<xsl:call-template name="_print_content_stylesheet_path"/>
					</xsl:attribute>
				</link>
				<base target="content"/>
				<title/>
			</head>
			<body>
				<xsl:for-each select="//Section[count(@IDREF) = 0]">
					<xsl:variable name="aname">
						<xsl:call-template name="print_section_aname"/>
					</xsl:variable>
					<xsl:variable name="indent" select="count(ancestor::Section) + 2"/>
					<xsl:element name="h{$indent}">
						<a>
							<xsl:attribute name="href">
								<xsl:call-template name="print_html_content_file_path">
									<xsl:with-param name="portal_document" select="$portal_document"/>
									<xsl:with-param name="url" select="'yes'"/>
									<xsl:with-param name="relative" select="'yes'"/>
								</xsl:call-template>
								<xsl:text>#</xsl:text>
								<xsl:value-of select="$aname"/>
							</xsl:attribute>
							<xsl:call-template name="_print_section_title"/>
						</a>
					</xsl:element>
					<br/>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
	<!--Prints the index HTML file-->
	<!--no supposition upon the current node; the portal_document should be provided as a parameter-->
	<xsl:template name="write_index">
		<xsl:param name="portal_document"/>
		<html>
			<head>
				<meta name="robots" content="noindex, follow"/>
				<link rel="StyleSheet" type="text/css">
					<xsl:attribute name="href">
						<xsl:call-template name="_print_content_stylesheet_path"/>
					</xsl:attribute>
				</link>
				<base target="content"/>
				<xsl:variable name="portal">
					<xsl:call-template name="print_portal_information"/>
				</xsl:variable>
				<title>
					<xsl:value-of select="$portal/Portal/Title"/>
				</title>
			</head>
			<body>
				<xsl:call-template name="_print_top_index">
					<xsl:with-param name="portal_document" select="$portal_document"/>
				</xsl:call-template>
			</body>
		</html>
	</xsl:template>
	<xsl:template name="_write_inner_frame">
		<xsl:param name="menu_file"/>
		<xsl:param name="content_file"/>
		<html>
			<head>
				<meta name="robots" content="noindex, follow"/>
				<title>
					<xsl:variable name="title">
						<xsl:apply-templates select="Title"/>
					</xsl:variable>
					<xsl:value-of select="normalize-space($title)"/>
				</title>
				<script language="javascript">
document.write('&lt;frameset border="0" cols="15%,*">');
document.write('&lt;frame src="<xsl:value-of select="$menu_file"/>">');
url = parent.location;
extended_url = (url.search ? ('#' + unescape(url.search.substring(1))) : '');
document.write('&lt;frame name="content" src="<xsl:value-of select="$content_file"/>' + extended_url + '">');
document.write('&lt;\/frameset>');</script>
			</head>
			<body/>
		</html>
	</xsl:template>
	<!--Prints the outer most HTML frame-->
	<!--no supposition upon the current node; the portal_document should be provided as a parameter-->
	<!--The 'index_file' parameter must be provided, and equal to the relative URL of the HTML index file (displayed on the top)-->
	<!--The 'inner_frame_file' parameter must be provided, and equal to the relative URL of the HTML inner frame file (displayed on the bottom)-->
	<xsl:template name="write_top">
		<xsl:param name="index_file"/>
		<xsl:param name="inner_frame_file"/>
		<html>
			<head>
				<meta name="robots" content="index, follow"/>
				<script type="text/javascript" language="javascript">
					<xsl:attribute name="src">
						<xsl:call-template name="_print_javascript_path"/>
					</xsl:attribute>
				</script>
				<title>
					<xsl:variable name="title">
						<xsl:apply-templates select="Title"/>
					</xsl:variable>
					<xsl:value-of select="normalize-space($title)"/>
				</title>
			</head>
			<frameset border="0" rows="95,*">
				<frame scrolling="no">
					<xsl:attribute name="src">
						<xsl:value-of select="$index_file"/>
					</xsl:attribute>
				</frame>
				<frame name="lower_frameset">
					<xsl:attribute name="src">
						<xsl:value-of select="$inner_frame_file"/>
					</xsl:attribute>
				</frame>
			</frameset>
			<body/>
		</html>
	</xsl:template>
	<xsl:template name="_print_php_audit">
		<xsl:text disable-output-escaping="yes">&lt;?php
require '</xsl:text>
		<xsl:value-of select="$php_url"/>
		<xsl:text disable-output-escaping="yes">';
$page_name = "</xsl:text>
		<xsl:value-of select="/Document/@ID"/>
		<xsl:text disable-output-escaping="yes">";
$database = connect_to_db("</xsl:text>
		<xsl:value-of select="$mysql_host_name"/>
		<xsl:text>", "</xsl:text>
		<xsl:value-of select="$mysql_user_name"/>
		<xsl:text>", "</xsl:text>
		<xsl:value-of select="$mysql_user_password"/>
		<xsl:text>", "</xsl:text>
		<xsl:value-of select="$mysql_database_name"/>
		<xsl:text disable-output-escaping="yes">");
$table_name = get_table_name();
$result = mysql_query("SELECT * FROM $table_name WHERE ID='$page_name';", $database);
if (!$row = mysql_fetch_row($result))
{
	mysql_query("INSERT INTO $table_name (ID, HIT) VALUES('$page_name', 0);", $database);
	$row = mysql_fetch_row($result);
}
$new_value = $row[1] + 1;
mysql_query("UPDATE $table_name SET HIT=$new_value WHERE ID='$page_name';", $database);
	?&gt;</xsl:text>
	</xsl:template>
</xsl:stylesheet>
