<?xml version="1.0" encoding="ISO-8859-1"?>
<!--Takes the portal XML file and generates the general index-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:import href="Common.xsl"/>
	<xsl:output method="html" standalone="yes" indent="yes"/>
	<xsl:key name="key_ref_id" match="Ref2" use="@ID"/>
	<xsl:template match="Portal">
		<xsl:variable name="references">
			<References>
				<xsl:for-each select="//Document[not(@type = 'HTML')]">
					<xsl:variable name="xml_file">
						<xsl:call-template name="print_xml_file_path">
							<xsl:with-param name="document_id" select="@IDREF"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:apply-templates select="document($xml_file)/Document//Ref">
						<xsl:with-param name="portal_document" select="."/>
					</xsl:apply-templates>
					<xsl:apply-templates select="document($xml_file)/Document//Reference">
						<xsl:with-param name="portal_document" select="."/>
					</xsl:apply-templates>
				</xsl:for-each>
			</References>
		</xsl:variable>
		<html>
			<head>
				<meta name="robots" content="index, nofollow"/>
				<xsl:apply-templates select="Keywords"/>
				<link rel="StyleSheet" type="text/css">
					<xsl:attribute name="href">
						<xsl:call-template name="_print_content_stylesheet_path"/>
					</xsl:attribute>
				</link>
				<title>Index</title>
			</head>
			<body>
				<p>Here is the list of all the abbreviations, softwares and technologies mentioned in this site.</p>
				<table class="indices">
					<tr>
						<th>Name</th>
						<th>Definition</th>
						<th>Where</th>
					</tr>
					<xsl:for-each select="$references/References/Ref2[generate-id() =
generate-id(key('key_ref_id', @ID))]">
						<xsl:sort order="ascending" select="@ID"/>
						<tr>
							<xsl:if test="(position() mod 2) = 0">
								<xsl:attribute name="class">even</xsl:attribute>
							</xsl:if>
							<td>
								<a name="{@ID}">
									<xsl:call-template name="print_reference_name">
										<xsl:with-param name="reference" select="Reference"/>
									</xsl:call-template>
								</a>
							</td>
							<td>
								<xsl:call-template name="print_reference_description">
									<xsl:with-param name="reference" select="Reference"/>
								</xsl:call-template>
							</td>
							<td>
								<table>
									<xsl:for-each select="../Ref2[@ID = current()/@ID]">
										<xsl:sort order="ascending" select="Document/@IDREF"/>
										<xsl:if test="count(preceding-sibling::Ref2[@ID = current()/@ID]/Document[@IDREF = current()/Document/@IDREF and (count(@xml:lang) = 0 or @xml:lang = current()/Document/@xml:lang)]) = 0">
											<tr>
												<td>
													<xsl:variable name="doc">
														<Doc IDREF="{Document/@IDREF}"/>
													</xsl:variable>
													<xsl:apply-templates select="$doc"/>
												</td>
											</tr>
										</xsl:if>
									</xsl:for-each>
								</table>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="Document//Ref">
		<xsl:param name="portal_document"/>
		<Ref2 ID="{@IDREF}">
			<!--xsl:attribute name="section"><xsl:choose><xsl:when test="$section != ''"><xsl:call-template name="print_section_aname"><xsl:with-param name="section" select="$section"/></xsl:call-template></xsl:when><xsl:otherwise><xsl:call-template name="print_section_aname"><xsl:with-param name="section" select="ancestor::Section"/></xsl:call-template></xsl:otherwise></xsl:choose></xsl:attribute-->
			<!--Document>
				<xsl:attribute name="IDREF"><xsl:value-of select="/Document/@ID"/></xsl:attribute>
			</Document-->
			<xsl:copy-of select="$portal_document"/>
			<xsl:call-template name="print_reference">
				<xsl:with-param name="reference_id" select="@IDREF"/>
			</xsl:call-template>
		</Ref2>
	</xsl:template>
	<xsl:template match="Document//Reference">
		<xsl:param name="portal_document"/>
		<Ref2 ID="{@ID}">
			<!--xsl:attribute name="section"><xsl:choose><xsl:when test="$section != ''"><xsl:call-template name="print_section_aname"><xsl:with-param name="section" select="$section"/></xsl:call-template></xsl:when><xsl:otherwise><xsl:call-template name="print_section_aname"><xsl:with-param name="section" select="ancestor::Section"/></xsl:call-template></xsl:otherwise></xsl:choose></xsl:attribute-->
			<!--Document>
				<xsl:attribute name="IDREF"><xsl:value-of select="/Document/@ID"/></xsl:attribute>
			</Document-->
			<xsl:copy-of select="$portal_document"/>
			<xsl:copy-of select="current()"/>
		</Ref2>
	</xsl:template>
	<!--Prints the name text of the reference-->
	<!--the parameter reference must be defined and should point to a Reference element-->
	<xsl:template name="print_reference_name">
		<xsl:param name="reference"/>
		<xsl:choose>
			<xsl:when test="count($reference/Description) > 0">
				<xsl:variable name="ref">
					<Reference ID="{$reference/@ID}" long="yes" p="yes" a="yes">
						<xsl:if test="count($reference/@href) > 0">
							<xsl:attribute name="href">
								<xsl:value-of select="$reference/@href"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:copy-of select="$reference/Name"/>
						<xsl:copy-of select="$reference/Description"/>
					</Reference>
				</xsl:variable>
				<xsl:apply-templates select="$ref"/>
			</xsl:when>
			<xsl:when test="count($reference/Name/Abreviation) > 0">
				<xsl:variable name="ref">
					<Reference ID="{$reference/@ID}" a="yes">
						<xsl:copy-of select="$reference/Name"/>
					</Reference>
				</xsl:variable>
				<xsl:apply-templates select="$ref"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$reference/@ID"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the description text of the reference-->
	<!--the parameter reference must be defined and should point to a Reference element-->
	<xsl:template name="print_reference_description">
		<xsl:param name="reference"/>
		<xsl:choose>
			<xsl:when test="count($reference/Description) > 0">
				<xsl:choose>
					<xsl:when test="count($reference/Description/Lang) > 0">
						<xsl:apply-templates select="$reference/Description/Lang[@xml:lang = $lang]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="$reference/Description"/>
					</xsl:otherwise>
				</xsl:choose>
				<!--xsl:apply-templates select="$reference/Description"/-->
				<!--xsl:value-of select="$reference/Description"/-->
			</xsl:when>
			<xsl:when test="count($reference/Name/Abreviation) > 0">
				<xsl:call-template name="print_abbreviation_description">
					<xsl:with-param name="abbreviation" select="$reference/Name/Abreviation"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
